{%import "utils.js" as utils%}
<div class="container col-sm-12 well" id="credentials{{prefix}}">
    {% for field in args %}
        <div class="row">
            <div class="form-group col-sm-10" style="padding-right:10px;">
                <label for="{{field[0]}}{{prefix}}">{{field[1]}}</label>
                <input type="text" class="form-control" id="{{field[0]}}{{prefix}}" name="{{field[0]}}" value="{{this.options.get(field[0]) or ""}}">
            </div>
        </div>
    {% endfor %}
</div>

<script>
    $('#credentials{{prefix}} *').filter(':input').filter(function(){ return $(this).attr("name")})
    .change(function(){
        var options = {};
        options[$(this).attr("name")]=$(this).val();
        {{utils.savePixiedustOptions(this.options.get('cell_id'), 'options')}}
    });
</script>