
@import url(https://ibm-cds-labs.github.io/simple-data-pipe-connector-flightstats/css/weather-icons.min.css);

.chart-wrapper {
  margin: 10px;
  padding: 10px;
}
.chart-wrapper .chart-title {
  border-bottom: 1px solid #00b4a0;
  color: #ffffff;
  font-size: 24px;
  font-weight: 200;
  padding: 0 0 5px;
}
.chart-wrapper .chart-title .memo {
  color: #a6266e;
  float: right;
  font-size: 13px;
  line-height: 26px;
}
.chart-wrapper.flight-info .search {
  color: #a6266e;
  cursor: pointer;
  font-weight: 400;
}
.chart-wrapper.flight-info .search:hover {
  text-decoration: underline;
}
.chart-wrapper .chart-stage {
  overflow: hidden;
  position: relative;
  margin: 10px 0px 5px;
}
.chart-wrapper .chart-stage .form-title {
  margin: 10px 0;
}
.chart-wrapper .chart-notes {
  color: #a6266e;
  font-size: initial;
}
.pixiedust-spinner {
  color: #fff;
  font-size: 24px;
  float: right;
}
.pixiedust .modal-header {
  background-color: rgba(0,0,0,0.45); /*#01021F;*/
  border-color: #00b4a0;
  color: #ffffff;
}
.pixiedust .modal-body {
  padding: 10px;
}
.pixiedust .modal-dialog .btn.focus,
.pixiedust .modal-dialog .btn:focus {
  outline: none;
}
.pixiedust .modal-dialog .btn-cancel,
.pixiedust .modal-dialog .btn-ok {
  display: none;
}
.pixiedust .modal-dialog .btn-back {
  background-color: #ffffff;
  border: 2px solid #00b4a0;
  color: #00b4a0;
  float: left;
  padding: 0.625em 1.375em;
}
.pixiedust .modal-dialog .btn-back:hover {
  background-color: #00b4a0;
  border-color: #00b4a0;
  color: #fff;
}
.pixiedust .modal-dialog .btn-next,
.pixiedust .modal-dialog .btn-ok {
  background-color: #00b4a0;
  border: 2px solid #00b4a0;
  color: #fff;
  padding: 0.625em 1.375em;
}
.pixiedust .modal-dialog .btn-next:hover,
.pixiedust .modal-dialog .btn-ok:hover {
  background-color: rgba(0,0,0,0.5);
  border: 2px solid #00b4a0;
  color: #00b4a0;
}
.pixiedust .modal-dialog .btn-restart {
  background-color: #a6266e;
  border: 2px solid #a6266e;
  color: #fff;
  padding: 0.625em 1.375em;
}
.pixiedust .modal-dialog .btn-restart:hover {
  background-color: rgba(0,0,0,0.5);
  border: 2px solid #a6266e;
  color: #a6266e;
}
.pixiedust .modal-dialog .btn-search {
  background-color: rgba(0,0,0,0.5);
  border: 2px solid #00b4a0;
  color: #00b4a0;
  padding: 0.625em 1.375em;
}
.pixiedust .modal-dialog .btn-search:hover {
  background-color: #00b4a0;
  border-color: #00b4a0;
  color: #fff;
}
.pixiedust .modal-footer {
  border-top: 0px;
  padding: 20px 30px;
}
.pixiedust .modal-dialog svg text {
  fill: black;
  font-size: 11px;
  font-weight: normal;
}


.pixiedust .modal-title {
  font-weight: 200;
  letter-spacing: 1px;
}
.modal-dialog-flightpredictform {
  width: 95% !important;
}
.modal-dialog-flightpredictform .chart-title {
  text-align: left;
}
.pixiedust .modal-dialog-flightpredictform .modal-content,
.pixiedust .modal-dialog-flightpredictdata .modal-content {
  background-image: url(https://ibm-cds-labs.github.io/simple-data-pipe-connector-flightstats/north_america_night.jpg);
  /*background-image: url(http://localhost:8888/notebooks/north-america-00.jpg);*/
  background-repeat: no-repeat;
  background-size: cover;
}
.modal-dialog-flightpredictform .modal-content::after,
.modal-dialog-flightpredictdata .modal-content::after {
    top: 0;
    left: 0;
    height: 100%;
    width: 100%;
    content: "";
    position: absolute;
    display: block;
    opacity: 0.5;
    background: -webkit-linear-gradient(left, #1d3649 0%, #325C80 50%);
    background: linear-gradient(to right, #1d3649 0%, #325C80 50%);
}
.modal-dialog-flightpredictform .modal-content > div,
.modal-dialog-flightpredictdata .modal-content > div {
  position: relative;
  z-index: 1;
}
.pixiedust .modal-dialog.modal-dialog-flightpredictform .btn-back:not(:hover),
.pixiedust .modal-dialog.modal-dialog-flightpredictdata .btn-back:not(:hover) {
  background-color: rgba(0,0,0,0.5);
}
.modal-dialog-flightpredictform .flight-info {
  background-color: rgba(0, 0, 0, 0.55);
  letter-spacing: 1px;
  margin: 25px auto;
  padding: 10px 25px 0;
  display: inline-block;
}
.modal-dialog-flightpredictform svg {
  fill: #00b4a0;
}
.fp-more-link {
  color: #fff;
  cursor: pointer;
  text-align: right;
  vertical-align: middle;
}
.fp-more-link:hover span:first-child {
  /*color:#00b4a0;*/
  text-decoration: underline;
}
.fp-more-link:hover svg {
  fill:#ffffff;
}
.fp-more-link span:first-child {
  display: block;
  font-size: 18px;
  font-weight: 200;
  line-height: 20px;
  margin-bottom: 10px;
}


.modal-dialog-flightpredictform .modal-content .modal-footer,
.modal-dialog-flightpredictdata .modal-content .modal-footer {
  background-color: rgba(0,0,0,0.45); /*#01021F;*/
  border-top: 1px solid #00b4a0;
}

.flight-info .chart-title,
.flight-info .chart-stage {
  color: #ffffff;
}
.flight-info .chart-title {
  border-color: #00b4a0;
}
.flight-info input,
.flight-info select {
  color: #152935;
  z-index: 10;
}
.flight-info input:disabled,
.flight-info select:disabled {
  background-color: #ddd;
  color: #777;
}
.flight-predict-message {
  background-color: #a6266e;
  padding: 10px;
  display: none;
}

.modal-dialog-flightpredictdata {
  width: 95% !important;
}
.modal-dialog-flightpredictform .btn-restart {
  display: none;
}
.modal-dialog-flightpredictdata .btn-next {
  display: none;
}
.modal-header .note {
  color: lightgray;
  display: inline-block;
  float: right;
  font-size: 12px;
  padding: 4px 10px;
}
.pixiedust-formfield {
  /*padding: 10px;*/
}
.pixiedust-formfield .required {
  color: #a6266e;
}
.pixiedust-formfield label {
  font-size: 15px;
  font-weight: 200;
  letter-spacing: 2px;
  margin-bottom: 3px;
}
.pixiedust-formfield input,
.pixiedust-formfield select {
  border: 1px solid #1d3649;
  font-size: 16px;
  font-weight: 300;
  margin: 0 0 24px;
  padding: 3px 5px;
}
.pixiedust-formfield input:focus,
.pixiedust-formfield input.focus,
.pixiedust-formfield select:focus,
.pixiedust-formfield select.focus {
  border-color: #a6266e;
}

.tab-pane-flightpredictdata ul {
  list-style: outside none none;
  padding: 0px;
}
.tab-pane-flightpredictdata li {
  background-color: rgba(0, 0, 0, 0.25);
  border-left: 5px solid transparent;
  color: #ffffff;
  display: block;
  font-size: 1.125em;
  margin-bottom: 15px;
  padding: 0px;
}
.tab-pane-flightpredictdata li:hover,
.tab-pane-flightpredictdata li.expanded {
  border-color: #999;
}
.tab-pane-flightpredictdata li > div:first-child {
  cursor: pointer;
  font-weight: 500;
  padding: 15px;
}
.tab-pane-flightpredictdata li.expanded > div:first-child,
.tab-pane-flightpredictdata li:hover > div:first-child {
  background-color: rgba(0,0,0,0.55);
}
#prediction-models,
#weather-forecasts {
  height: calc(30vh + 30px);
}
#prediction-models .chart-stage,
#weather-forecasts .chart-stage {
  height: calc(100% - 40px);
  overflow: auto;
}
.prediction-model-title > span:nth-child(2),
.weather-forecast-title > span:nth-child(2) {
  float: right;
  font-weight: 300;
}
.prediction-model,
.weather-forecast {
  display: none;
  line-height: 1.5em;
  padding: 10px;
}
.prediction-model {
  font-weight: 400;
  font-size: 18px;
}
.weather-forecast {
  padding-left: 20px;
}
.prediction-model span:first-child {
  line-height: 1.5em;
  padding: 10px;
}
.prediction-model span:nth-child(2) {
  color: #00b4a0;
  float: right;
  font-weight: 600;
}
.prediction-model span.delayed {
  color: #a6266e;
}
.airport-marker-info h3,
.flight-path-info h3 {
  font-size: 20px;
  margin: 0;
  padding: 10px 0;
}
.airport-marker-info > div {
  font-size: 14px;
}
.airport-marker-info > div:last-child {
  padding: 10px 0;
}
.flight-path-info > div {
  padding: 2px 0;
}
.flight-path-info > div:nth-child(4) {
  padding-top: 6px;
}
.flight-path-info span:nth-child(2) {
  float: right;
  margin-left: 10px;
}
.fp-progress {
  font-size: 20px;
  font-weight: 400;
  line-height: 60px;
  bottom: 20px;
  position: absolute;
  color: #ffffff;
  width: 100%;
}
.fp-dep,
.fp-arr-one,
.fp-arr-two {
  border: 5px solid #a6266e;
  border-radius: 50%;
  display: none;
  opacity: 0.5;
  height: 75px;
  width: 75px;
}
.fp-path-one,
.fp-path-two {
  border-bottom: 5px solid #a6266e;
  bottom: 7px;
  display: inline-block;
  height: 50px;
  margin: 0 -10px;
  opacity: 0.5;
  position: relative;
  vertical-align: text-bottom;
  width: 0;
}
.fp-dep {
  display: inline-block;
  opacity: 1;
}

.flight-one,
.flight-two {
  display: inline-block;
  vertical-align: top;
  width: 325px;
  padding: 10px;
  text-align: left;
}
.flight-two {
  overflow: hidden;
  padding-left: 0;
  padding-right: 0;
  width: 0;
}

#ui-datepicker-div {
  z-index: 1500 !important;
}



.weather-forecast > div {
  margin: 0;
  padding: 15px 0 25px 10px;
}
.weather-forecast > div:first-child {
  border-bottom: 1px solid #c6c6c6;
}
.fp-weather-temp {
  display: inline-block;
  font-size: 55px;
  vertical-align: top;
  width: 26%
}
.fp-weather-temp span {
  font-size: 20px;
  vertical-align: super;
}
.fp-weather-icon {
  display: inline-block;
  font-size: 48px;
  width: 24%
}
.fp-weather-info {
  display: inline-block;
  margin: 0 10px;
  width: calc(50% - 30px);
}
.fp-weather-info div {
  font-size: 14px;
  line-height: 16px;
}
.fp-weather-info div:first-child {
  font-size: 16px;
  font-weight: bold;
}

